@@ -10,8 +10,8 @@ This currently supports:
  * Python modules (./*.py, only in root directory)
  * Python packages (all directories with __init__.py)
  * Docbook-XML GNOME help files (help/<language>/{*.xml,*.omf,figures})
- * GtkBuilder (*.ui) [installed into prefix/share/<projectname>/]
- * Qt4 user interfaces (*.ui) [compiled with pykdeuic into Python modules]
+ * GtkBuilder and Qt4 user interfaces (*.ui) [installed into
+   prefix/share/<projectname>/]
  * D-Bus (*.conf and *.service)
  * PolicyKit (*.policy.in)
  * Desktop files (*.desktop.in) [into prefix/share/applications, or
@@ -38,7 +38,7 @@ author, license, etc.) in ./setup.py.
 # Author: Martin Pitt <martin.pitt@ubuntu.com>
 
 import os, os.path, fnmatch, stat, sys, subprocess
-import compiler # TODO: deprecated
+import ast
 import distutils.core
 
 from distutilsextra import __version__ as __pkgversion
@@ -88,7 +88,7 @@ def setup(**attrs):
     __data(attrs, src)
     __scripts(attrs, src)
     __stdfiles(attrs, src)
-    __gtkbuilder(attrs, src)
+    __ui(attrs, src)
     __manpages(attrs, src)
 
     if 'clean' not in sys.argv:
@@ -123,16 +123,17 @@ def __cmdclass(attrs):
     v.setdefault('build_help', build_help_auto)
     v.setdefault('build_i18n', build_i18n_auto)
     v.setdefault('build_icons', build_icons.build_icons)
-    v.setdefault('build_kdeui', build_kdeui_auto)
     v.setdefault('install', install_auto)
     v.setdefault('clean', clean_build_tree)
     v.setdefault('sdist', sdist_auto)
+    v.setdefault('pylint', pylint.pylint)
 
 def __modules(attrs, src):
     '''Default modules'''
 
     if 'py_modules' in attrs:
         for mod in attrs['py_modules']:
+            print mod
             src_markglob(src, os.path.join(mod, '*.py'))
         return
 
@@ -221,7 +222,7 @@ def __data(attrs, src):
     data_files = []
     for f in src.copy():
         if f.startswith('data/') and not f.startswith('data/icons/') and \
-                not f.endswith('.desktop.in') and not f.endswith('*.notifyrc.in'):
+                not f.endswith('.desktop.in') and not f.endswith('.notifyrc.in'):
             if not os.path.islink(f):
                 # symlinks are handled in install_auto
                 v.append((os.path.join('share', attrs['name'], os.path.dirname(f[5:])), [f]))
@@ -275,13 +276,16 @@ def __stdfiles(attrs, src):
         attrs.setdefault('data_files', []).append((os.path.join('share', 'doc',
             attrs['name']), readme))
 
-def __gtkbuilder(attrs, src):
-    '''Install GtkBuilder *.ui files'''
+def __ui(attrs, src):
+    '''Install GtkBuilder/Qt *.ui files'''
 
     ui = []
     for f in src_fileglob(src, '*.ui'):
-        contents = open(f).read()
-        if ('<interface>\n' in contents or '<interface ' in contents) and 'class="Gtk' in contents:
+        fd = open(f)
+        firstlines = fd.readline()
+        firstlines += '\n' + fd.readline()
+        fd.close()
+        if '<interface' in firstlines or '<ui version=' in firstlines:
             src_mark(src, f)
             ui.append(f)
     if ui:
@@ -330,16 +334,16 @@ def __add_imports(imports, file, attrs):
     This filters out modules which are shipped with Python itself.
     '''
     try:
-        ast = compiler.parseFile(file)
+        tree = ast.parse(open(file).read(), file)
 
-        for node in ast.node.nodes:
-            if isinstance(node, compiler.ast.Import):
-                for name, _ in node.names:
-                    if __external_mod(name, attrs):
-                        imports.add(name)
-            if isinstance(node, compiler.ast.From):
-                if __external_mod(node.modname, attrs):
-                    imports.add(node.modname)
+        for node in ast.walk(tree):
+            if isinstance(node, ast.Import):
+                for alias in node.names:
+                    if __external_mod(alias.name, attrs):
+                        imports.add(alias.name)
+            if isinstance(node, ast.ImportFrom):
+                if __external_mod(node.module, attrs):
+                    imports.add(node.module)
     except SyntaxError, e:
         print >> sys.stderr, 'WARNING: syntax errors in', file, ':', e
 
@@ -379,6 +383,8 @@ def __requires(attrs, src_all):
 
     # iterate over all *.py and scripts which are Python
     for s in src_all:
+        if s == 'setup.py':
+            continue
         if s.startswith('data' + os.path.sep):
             continue
         ext = os.path.splitext(s)[1]
@@ -399,7 +405,7 @@ def __provides(attrs, src_all):
     if 'provides' in attrs:
         return
 
-    provides = attrs.get('py_modules', [])
+    provides = list(attrs.get('py_modules', [])) # we need a copy here
     for p in attrs.get('packages', []):
         provides.append(p.replace(os.path.sep, '.'))
     attrs['provides'] = __filter_namespace(provides)
@@ -591,30 +597,6 @@ class build_i18n_auto(build_i18n.build_i18n):
             except:
                 pass
 
-class build_kdeui_auto(build_kdeui.build_kdeui):
-    def finalize_options(self):
-        global src
-
-        # add *.ui files which belong to KDE4
-        kdeui_files = []
-        for f in src_fileglob(src, '*.ui'):
-            fd = open(f)
-            # might be on the first or second line
-            if fd.readline().startswith('<ui version="') or \
-               fd.readline().startswith('<ui version="'):
-                src_mark(src, f)
-                kdeui_files.append(f)
-            fd.close()
-        if kdeui_files:
-            try:
-                uf = eval(self.ui_files)
-            except TypeError:
-                uf = []
-            uf += kdeui_files
-            self.ui_files = repr(uf)
-
-        build_kdeui.build_kdeui.finalize_options(self)
-
 #
 # Automatic sdist
 #
