@@ -1,4 +1,4 @@
-# Copyright (C) 2008-2010 LottaNZB Development Team
+# Copyright (C) 2008-2011 LottaNZB Development Team
 # 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -13,15 +13,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 
-import warnings
-
 from distutils.version import StrictVersion
 
-version = StrictVersion("0.5.4")
+version = StrictVersion("0.6")
 __version__ = str(version)
-
-# pkg_resources displays warnings for no valid reason when the application is
-# being launched locally.
-# Snippet by http://lucumr.pocoo.org/2008/2/19/sick-of-pkg-resources-warnings
-pkg_resources_warning = r"Module .*? is being added to sys\.path"
-warnings.filterwarnings("ignore", message=pkg_resources_warning, append=True)
