@@ -1,4 +1,4 @@
-# Copyright (C) 2008-2010 LottaNZB Development Team
+# Copyright (C) 2008-2011 LottaNZB Development Team
 # 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -13,19 +13,11 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 
-from kiwi.ui.delegates import Delegate
-
 from lottanzb import __version__
+from lottanzb.gui.framework import MainDelegateComponent
 
-class Dialog(Delegate):
-    gladefile = "about_dialog"
+class Dialog(MainDelegateComponent):
+    builder_file = "about_dialog"
     
-    def __init__(self):
-        Delegate.__init__(self)
-        
-        self.toplevel.set_version(__version__)
-        self.toplevel.set_name("LottaNZB")
-        self.toplevel.connect("response", self.on_response)
-    
-    def on_response(self, widget, response):
-        self.hide()
+    def create_ui(self):
+        self.get_toplevel().set_version(__version__)
