@@ -1,4 +1,4 @@
-# Copyright (C) 2008-2010 LottaNZB Development Team
+# Copyright (C) 2008-2011 LottaNZB Development Team
 # 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,5 +18,5 @@ __all__ = ["INSTALLED", "DATA_DIR", "HELP_DIR", "LOCALE_DIR"]
 INSTALLED = False
 
 DATA_DIR = "data"
-HELP_DIR = "help"
+HELP_DIR = "help/mallard"
 LOCALE_DIR = "build/mo"
